==> apache-cxf-3.5.9-src.zip: apache-cxf-3.5.9-src/systests/jaxrs/src/test/java/org/apache/cxf/systest/jaxrs/ApplicationInfoJaxrsFilter.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.systest.jaxrs;

import java.io.IOException;
import java.util.List;

import javax.annotation.Priority;
import javax.ws.rs.Priorities;
import javax.ws.rs.container.ContainerRequestContext;
import javax.ws.rs.container.ContainerRequestFilter;
import javax.ws.rs.ext.Provider;

@Provider
@Priority(Priorities.AUTHENTICATION + 1)
public class ApplicationInfoJaxrsFilter implements ContainerRequestFilter {

    @Override
    public void filter(ContainerRequestContext context) throws IOException {
        List<Object> matched = context.getUriInfo().getMatchedResources();
        if (matched.size() == 2 
            && ApplicationController.ApplicationControllerSub.class == matched.get(0)
            && ApplicationController.class == matched.get(1)) {
            context.getHeaders().putSingle("ApplicationInfo", "FilteredApplicationInfo");
        }
    }

}

==> apache-cxf-4.0.6-src.zip: apache-cxf-4.0.6-src/systests/jaxrs/src/test/java/org/apache/cxf/systest/jaxrs/ApplicationInfoJaxrsFilter.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.systest.jaxrs;

import java.io.IOException;
import java.util.List;

import jakarta.annotation.Priority;
import jakarta.ws.rs.Priorities;
import jakarta.ws.rs.container.ContainerRequestContext;
import jakarta.ws.rs.container.ContainerRequestFilter;
import jakarta.ws.rs.ext.Provider;

@Provider
@Priority(Priorities.AUTHENTICATION + 1)
public class ApplicationInfoJaxrsFilter implements ContainerRequestFilter {

    @Override
    public void filter(ContainerRequestContext context) throws IOException {
        List<Object> matched = context.getUriInfo().getMatchedResources();
        if (matched.size() == 2 
            && ApplicationController.ApplicationControllerSub.class == matched.get(0)
            && ApplicationController.class == matched.get(1)) {
            context.getHeaders().putSingle("ApplicationInfo", "FilteredApplicationInfo");
        }
    }

}
